{% if grains['os'] in ('Debian', 'Ubuntu') %}
hsh_exim_not_present:
  pkg.removed:
    - name: [exim4, exim4-base, exim4-config, exim4-daemon-light]

hsh_postfix_installed:
  pkg.installed:
    - name: postfix
    - require:
      - pkg: hsh_exim_not_present

hsh_postfix_configuration:
  file.managed:
    - name: /etc/postfix/main.cf
    - source: salt://postfix/nullclient/etc/postfix/main.cf
    - template: jinja
    - require:
      - pkg: hsh_postfix_installed

hsh_postfix_master_configuration:
  file.managed:
    - name: /etc/postfix/master.cf
    - source: salt://postfix/nullclient/etc/postfix/master.cf
    - template: jinja
    - require:
      - pkg: hsh_postfix_installed

# hack for ubuntu
hsh_postfix_mailname:
  file.managed:
    - name: /etc/mailname
    - source: salt://postfix/nullclient/etc/mailname
    - template: jinja
    - require:
      - pkg: hsh_postfix_installed

hsh_postfix_smtp_header_checks:
  file.managed:
    - name: /etc/postfix/smtp_header_checks
    - source: salt://postfix/nullclient/etc/postfix/smtp_header_checks
    - template: jinja
    - require:
      - pkg: hsh_postfix_installed

hsh_postfix_sender_canonical_exists:
  file.managed:
    - name: /etc/postfix/sender_canonical_maps
    - require:
      - pkg: hsh_postfix_installed

hsh_postfix_postmap_sender_canonical:
  cmd.run:
    - name: postmap /etc/postfix/sender_canonical_maps
    - require:
      - file: hsh_postfix_sender_canonical_exists

hsh_postfix_service_running:
  service.running:
    - name: postfix
    - reload: True
    - enable: True
    - watch:
      - file: hsh_postfix_configuration
      - file: hsh_postfix_master_configuration
      - file: hsh_postfix_smtp_header_checks
    - require:
      - file: hsh_postfix_configuration
      - file: hsh_postfix_master_configuration
      - pkg: hsh_postfix_installed
      - file: hsh_postfix_sender_canonical_exists
      - cmd: hsh_postfix_postmap_sender_canonical
      - file: hsh_postfix_smtp_header_checks
{% endif %}
  
